@@ -21,7 +21,9 @@
  *
  * @author Michal Babik <michal.babik@pm.me>
  */
+#ifdef DEBUG
 #include <stdio.h>
+#endif
 #include <string.h>
 #include <stdlib.h>
 #include <err.h>
@@ -46,6 +48,25 @@ static void setting_init (Setting *st_set);
 static void setting_copy2 (Setting       *st_dest,
                            const Setting *st_src);
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Create default Setting.
+ *
+ * @param[in] s_name  Setting's name
+ * @return    New Setting item
+ */
+static Setting * setting_new_default (const char *s_name)
+       __attribute__ ((returns_nonnull));
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief Set st_child Setting to be a child of st_parent.
+ *
+ * @param[out] st_parent  Parent Setting to set child to
+ * @param[out] st_child   Child setting to be assigned to st_parent Setting
+ * @return     none
+ */
+static void setting_set_child (Setting *st_parent,
+                               Setting *st_child);
+/*----------------------------------------------------------------------------*/
 /**
  * @brief  Set Setting type value
  *
@@ -285,9 +306,6 @@ setting_copy (const Setting *st_src)
 /*----------------------------------------------------------------------------*/
 /**
  * @brief  Create default Setting.
- *
- * @param[in] s_name  Setting's name
- * @return    New Setting item
  */
 static Setting *
 setting_new_default (const char *s_name)
@@ -559,10 +577,6 @@ settings_find_replace (Setting   *st_list,
 /*----------------------------------------------------------------------------*/
 /**
  * @brief Set st_child Setting to be a child of st_parent.
- *
- * @param[out] st_parent  Parent Setting to set child to
- * @param[out] st_child   Child setting to be assigned to st_parent Setting
- * @return     none
  */
 static void
 setting_set_child (Setting *st_parent,
@@ -575,6 +589,16 @@ setting_set_child (Setting *st_parent,
     }
 }
 /*----------------------------------------------------------------------------*/
+Setting * setting_get_child  (Setting *st_setting)
+{
+    if (setting_get_type (st_setting) == SET_VAL_SETTING ||
+        setting_get_type (st_setting) == SET_VAL_ARRAY) {
+
+        return st_setting->data.st_child;
+    }
+    return NULL;
+}
+/*----------------------------------------------------------------------------*/
 /**
  * @brief  Append Setting st_child to child list of Setting st_parent
  */
